@@ -79,7 +79,7 @@ public:
 extern std::list<DiceSet>   sets;
 extern DiceSetModelRef      setsModel;
 extern bool                 configurationChanged;
-extern Lum::Model::SizeTRef currentSet;
+extern Lum::Model::ULongRef currentSet;
 
 extern bool LoadConfig();
 extern bool SaveConfig();
