@@ -46,8 +46,8 @@ public:
 class RangeDialog : public Lum::Dlg::ActionDialog
 {
 private:
-  Lum::Model::SizeTRef  startModel;
-  Lum::Model::SizeTRef  endModel;
+  Lum::Model::ULongRef  startModel;
+  Lum::Model::ULongRef  endModel;
 
   Lum::Model::ActionRef okAction;
 
@@ -55,8 +55,8 @@ private:
 
 public:
   RangeDialog()
-   : startModel(new Lum::Model::SizeT(1)),
-     endModel(new Lum::Model::SizeT(6)),
+   : startModel(new Lum::Model::ULong(1)),
+     endModel(new Lum::Model::ULong(6)),
      okAction(new Lum::Model::Action()),
      hasResult(false)
   {
@@ -96,12 +96,12 @@ public:
     return hasResult;
   }
 
-  void GetResult(size_t &start, size_t& end)
+  void GetResult(unsigned long &start, unsigned long& end)
   {
     assert(hasResult);
 
-    start=*startModel;
-    end=*endModel;
+    start=startModel->Get();
+    end=endModel->Get();
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -120,7 +120,7 @@ public:
           !startModel->IsNull() &&
           endModel.Valid() &&
           !endModel->IsNull() &&
-          *endModel>=*startModel) {
+          endModel->Get()>=startModel->Get()) {
         okAction->Enable();
       }
       else {
@@ -131,7 +131,7 @@ public:
     Lum::Dlg::ActionDialog::Resync(model,msg);
   }
 
-  static bool GetRange(Lum::OS::Window* parent, size_t& start, size_t& end)
+  static bool GetRange(Lum::OS::Window* parent, unsigned long& start, unsigned long& end)
   {
     RangeDialog *dlg;
     bool        res;
@@ -278,9 +278,9 @@ void DiceEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
     }
   }
   else if (model==addNumbersAction && addNumbersAction->IsFinished()) {
-    bool   result=false;
-    size_t start=0;
-    size_t end=0;
+    bool          result=false;
+    unsigned long start=0;
+    unsigned long end=0;
 
     result=RangeDialog::GetRange(GetWindow(),start,end);
 
