@@ -91,8 +91,8 @@ void GameArea::CalcAreaSize(size_t width, size_t height)
 
   std::list<DiceSet>::const_iterator iter=sets.begin();
 
-  if (*currentSet>0) {
-    std::advance(iter,*currentSet-1);
+  if (currentSet->Get()>0) {
+    std::advance(iter,currentSet->Get()-1);
   }
 
   cellSize=font->height;
@@ -227,8 +227,8 @@ void GameArea::RedrawArea()
                         0,0,areaWidth,areaHeight,
                         0,0,areaWidth,areaHeight);
 
-  if (*currentSet>0) {
-    std::advance(iter,*currentSet-1);
+  if (currentSet->Get()>0) {
+    std::advance(iter,currentSet->Get()-1);
   }
 
   for (std::list<Dice>::const_iterator dice=iter->dices.begin();
@@ -371,8 +371,8 @@ bool GameArea::HandleMouseEvent(const Lum::OS::MouseEvent& event)
     xi=distance;
     yi=distance;
 
-    if (*currentSet>0) {
-      std::advance(iter,*currentSet-1);
+    if (currentSet->Get()>0) {
+      std::advance(iter,currentSet->Get()-1);
     }
 
     for (std::list<Dice>::iterator dice=iter->dices.begin();
